<?php

namespace App\Filament\Resources;

use App\Filament\Resources\ItemsResource\Pages;
use App\Filament\Resources\ItemsResource\RelationManagers;
use App\Models\Items;
use Filament\Forms;
use Filament\Resources\Form;
use Filament\Resources\Resource;
use Filament\Resources\Table;
use Filament\Tables;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Tables\Columns\BooleanColumn;
use Filament\Tables\Columns\TextColumn;
use Filament\Forms\Components\TextInput;
use Filament\Forms\Components\Toggle;

class ItemsResource extends Resource
{
    protected static ?string $model = Items::class;

    protected static ?string $navigationIcon = 'heroicon-o-collection';

    protected static ?string $navigationGroup = 'Silent Auction';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                TextInput::make('item_assigned_num')
                  ->label('Item Number'),
                TextInput::make('item_desc')
                  ->label('Description'),         
                TextInput::make('item_min_bid')
                  ->label('Minimum Bid')
                  ->mask(
                      fn (TextInput\Mask $mask) => $mask->money(
                          prefix: '$',
                          thousandsSeparator: ',',
                          decimalPlaces: 2,
                          isSigned: false
                      )
                  ),   
                  TextInput::make('item_est_value')
                  ->label('Estimated Value')
                  ->mask(
                      fn (TextInput\Mask $mask) => $mask->money(
                          prefix: '$',
                          thousandsSeparator: ',',
                          decimalPlaces: 2,
                          isSigned: false
                      )
                  ),       
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                TextColumn::make('item_assigned_num')
                    ->label('Item Number')
                    ->sortable(),
                TextColumn::make('item_desc')
                    ->label('Description'),
                TextColumn::make('item_min_bid')
                    ->label('Minimum Bid')
                    ->money('usd', 'true')
                    ->sortable(), 
                TextColumn::make('item_est_value')
                    ->label('Estimated Value')
                    ->money('usd', 'true')
                    ->sortable(),            
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\DeleteBulkAction::make(),
            ])
            ->defaultSort('item_assigned_num');
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListItems::route('/'),
            'create' => Pages\CreateItems::route('/create'),
            'edit' => Pages\EditItems::route('/{record}/edit'),
        ];
    }    
}
